@@ -12,3 +12,11 @@
 #' @import magrittr
 ## usethis namespace: end
 NULL
+
+.onLoad <- function(libname, pkgname) {
+  if (getRversion() >= "2.15.1") {
+    utils::globalVariables(
+      c(".", ".SD", ".N")
+    )
+  }
+}
